=======
History
=======

0.1.0 (2023-10-14)
------------------

* we started.

0.1.1 (2024-02-04)
------------------

* ORC and HP is working
* Fluid screening included for mixtures
* everything only with REFPROP
